@@ -58,6 +58,8 @@ Z = TypeVar("Z", bound="A")
 S = TypeVar("S", bound="miss")  # type: ignore # miss not defined on purpose # noqa: F821
 W = NewType("W", str)
 P = typing_extensions.ParamSpec("P")
+P_args = P.args  # type:ignore[attr-defined]
+P_kwargs = P.kwargs  # type:ignore[attr-defined]
 P_co = typing_extensions.ParamSpec("P_co", covariant=True)  # type: ignore
 P_contra = typing_extensions.ParamSpec("P_contra", contravariant=True)  # type: ignore
 P_bound = typing_extensions.ParamSpec("P_bound", bound=str)  # type: ignore
@@ -163,6 +165,9 @@ else:
         pytest.param(Match[str], "typing", "Match", (str,), id="Match_parametrized"),
         pytest.param(IO, "typing", "IO", (), id="IO"),
         pytest.param(W, "typing", "NewType", (str,), id="W"),
+        pytest.param(P, "typing", "ParamSpec", (), id="P"),
+        pytest.param(P_args, "typing", "ParamSpecArgs", (), id="P_args"),
+        pytest.param(P_kwargs, "typing", "ParamSpecKwargs", (), id="P_kwargs"),
         pytest.param(Metaclass, __name__, "Metaclass", (), id="Metaclass"),
         pytest.param(Slotted, __name__, "Slotted", (), id="Slotted"),
         pytest.param(A, __name__, "A", (), id="A"),
